@@ -3,20 +3,20 @@ use strict;
 use warnings;
 BEGIN { $ENV{PERL_ANYEVENT_MODEL} = "POE" }
 
-our $VERSION = '0.001_01';
+our $VERSION = '0.002';
 $VERSION = eval $VERSION;
 
 1;
 
 =head1 NAME
 
-Message::Passing::Syslog - input and output logstash messages from/to Syslog.
+Message::Passing::Syslog - input and output messages from/to Syslog.
 
 =head1 SYNOPSIS
 
-    logstash --output STDOUT --input Syslog --input_options '{"port":"5140"}'
+    message-pass --output STDOUT --input Syslog --input_options '{"port":"5140"}'
 
-    logstash --input STDIN --output Syslog --output_options 'xxx'
+    message-pass --input STDIN --output Syslog --output_options 'xxx'
 
 =head1 DESCRIPTION
 
